# Convert labelme json file to png image 
```convert_labelme_to_image.py --path_load_json_files="..." --path_save_masks="..."```

# Start training
```training.py --path_config_file="..."```

# Start prediciton
```predicition.py  --path_config_file="..."```
